@@ -46,7 +46,7 @@
 #'     + `variables = list(gear = "sequential", hp = c(100, 120))`
 #'     + See the Examples section below for more.
 #' @param newdata Grid of predictor values at which we evaluate the comparisons.
-#' + `NULL` (default): Unit-level contrasts for each observed value in the original dataset (empirical distribution).
+#' + `NULL` (default): Unit-level contrasts for each observed value in the original dataset (empirical distribution). See [insight::get_data()]
 #' + data frame: Unit-level contrasts for each row of the `newdata` data frame.
 #' + string:
 #'   - "mean": Contrasts at the Mean. Contrasts when each predictor is held at its mean or mode.
@@ -285,11 +285,10 @@ comparisons <- function(model,
     }
     
     # more sanity chekcs
-    
-    conf_level <- sanitize_conf_level(conf_level, ...)
     sanity_dots(model, ...)
+    sanity_df(df, newdata)
+    conf_level <- sanitize_conf_level(conf_level, ...)
     checkmate::assert_number(eps, lower = 1e-10, null.ok = TRUE)
-    checkmate::assert_number(df, lower = 1)
 
     # transforms
     sanity_comparison(comparison)
@@ -323,11 +322,17 @@ comparisons <- function(model,
     if ("modeldata" %in% names(dots)) {
         modeldata <- dots[["modeldata"]]
     } else {
+        addvar <- NULL
         if (isTRUE(checkmate::check_character(by))) {
-            addvar <- by
-        } else if (isTRUE(checkmate::check_data_frame(by))) {
-            addvar <- colnames(by)
-        } else {
+            addvar <- c(addvar, by)
+        }
+        if (isTRUE(checkmate::check_data_frame(by))) {
+            addvar <- c(addvar, colnames(by))
+        }
+        if (isTRUE(checkmate::check_string(wts))) {
+            addvar <- c(addvar, wts)
+        }
+        if (is.null(addvar)) {
             addvar <- FALSE
         }
         modeldata <- get_modeldata(model, additional_variables = addvar)
