@@ -43,15 +43,15 @@ set_coef.glmmTMB <- function(model, coefs, ...) {
     # predictions and delta method standard errors to be affected.
     # random parameters are ignored: named "b"
     # the order matters; I think we can rely on it, but this still feels like a HACK
+    # In particular, this assumes that the order of presentation in coef() is always: beta -> betazi -> betad
     out <- model
-    idx <- !names(out$fit$parfull) %in% c("theta", "b", "psi")
+    idx <- grepl("^beta", names(out$fit$parfull))
     if (length(coefs) == length(out$fit$parfull[idx])) {
         out$fit$parfull[idx] <- stats::setNames(coefs, names(out$fit$parfull)[idx])
     } else {
         insight::format_error("Unable to compute standard errors for this model.")
     }
-
-    idx <- !names(out$fit$par) %in% c("theta", "b", "psi")
+    idx <- grepl("^beta", names(out$fit$par))
     if (length(coefs) == length(out$fit$par[idx])) {
         out$fit$par[idx] <- stats::setNames(coefs, names(out$fit$par)[idx])
     } else {
