@@ -53,4 +53,11 @@ expect_snapshot_print(avg_comparisons(mod), "df-z")
 expect_snapshot_print(avg_comparisons(mod, df = 30), "df-t")
 
 
+# Issue #754: allow df vector
+mod <- lm(mpg ~ hp, mtcars)
+a <- predictions(mod, df = 1:32)
+b <- predictions(mod, df = 1)
+expect_equal(sum(a$p.value == b$p.value), 1)
+
+
 rm(list = ls())
\ No newline at end of file
