@@ -226,7 +226,7 @@ expect_equivalent(pred$conf.high, em$upper.HPD)
 # marginalmeans vs. emmeans
 requiet("emmeans")
 requiet("broom")
-expect_error(marginal_means(brms_factor, variables = "cyl_fac", type = "link"), pattern = "github.*issues")
+expect_error(marginal_means(brms_factor, variables = "cyl_fac", type = "link"))
 # emmeans::emmeans(brms_factor, specs = ~cyl_fac)
 
 
@@ -710,6 +710,11 @@ cmp <- comparisons(mod, type = "link")
 expect_inherits(cmp, "comparisons")
 
 
+# Issue #751: informative error on bad predition
+expect_error(comparisons(brms_logit_re, newdata = datagrid(firm = -10:8)),
+    pattern = "new.levels")
+cmp = comparisons(brms_logit_re, newdata = datagrid(firm = -10:8), allow_new_levels = TRUE)
+expect_inherits(cmp, "comparisons")
 
 
 
