@@ -181,5 +181,30 @@ p <- plot_slopes(mod, variables = "hp", condition = list("qsec" = "minmax", "gea
 expect_true("qsec" %in% colnames(p))
 
 
+
+# Issue #725: `newdata` argument in plotting functions
+mod <- lm(mpg ~ hp + am + factor(cyl), mtcars)
+p1 <- plot_predictions(mod, by = "am", newdata = datagridcf(am = 0:1), draw = FALSE)
+p2 <- avg_predictions(mod, by = "am", newdata = datagridcf(am = 0:1), draw = FALSE)
+expect_equivalent(p1$estimate, p2$estimate)
+expect_equivalent(p1$conf.low, p2$conf.low)
+p3 <- plot_predictions(mod, by = "am", draw = FALSE)
+p4 <- avg_predictions(mod, by = "am", draw = FALSE)
+expect_equivalent(p3$estimate, p4$estimate)
+expect_equivalent(p3$conf.low, p4$conf.low)
+expect_true(all(p1$conf.low != p3$conf.low))
+p5 <- plot_predictions(mod, condition = "am", draw = FALSE)
+p6 <- predictions(mod, newdata = datagrid(am = 0:1))
+expect_equivalent(p5$estimate, p6$estimate)
+expect_equivalent(p5$conf.low, p6$conf.low)
+expect_true(all(p1$conf.low != p5$conf.low))
+expect_true(all(p3$conf.low != p5$conf.low))
+expect_error(plot_predictions(mod, condition = "am", by = "am"))
+expect_error(plot_predictions(mod, newdata = mtcars))
+
+
+
+
+
 suppressWarnings(rm("threenum", .GlobalEnv))
 rm(list = ls())
\ No newline at end of file
