@@ -26,7 +26,7 @@ cmp2 <- tidy(cmp2)
 known <- c("mean(+10)", "mean(4) - mean(3)", "mean(5) - mean(4)", "mean(6) - mean(4)", 
 "mean(8) - mean(4)", "mean(8) - mean(6)")
 expect_true(all(known %in% cmp1$contrast))
-expect_equivalent(cmp1$estimate[3], cmp2$estimate[3] * 10)
+expect_equivalent(cmp1$estimate[6], cmp2$estimate[6] * 10)
 
 # informative errors
 expect_error(suppressWarnings(comparisons(mod, variables = list(gear = "blah"))), pattern = "variables")
@@ -40,15 +40,32 @@ expect_error(comparisons(mod, variables = list(cyl = "iqr")), pattern = "element
 
 # Binary variables
 mod <- glm(am ~ hp + vs, dat = mtcars, family = binomial)
-cmp1 <- comparisons(mod, variables = "vs")
-cmp2 <- comparisons(mod, variables = list(vs = 0:1))
 cmp3 <- comparisons(mod, variables = list(vs = 1))
-mfx <- slopes(mod, variables = "vs")
-expect_equivalent(cmp1$estimate, cmp2$estimate)
-expect_true(all(cmp1$estimate != mfx$estimate))
-expect_true(all(cmp1$estimate != cmp3$estimate))
+expect_inherits(cmp3, "comparisons")
 
 
 # Issue #582: sanitize_variables should reject reponse as 
 mod <- lm(mpg ~ hp + qsec, data = mtcars)
-expect_error(slopes(mod, variables = "mpg"), pattern = "outcome variable")
\ No newline at end of file
+expect_error(slopes(mod, variables = "mpg"), pattern = "outcome variable")
+
+
+# no need to include categorical focal variable when there is only one of them
+mod <- lm(mpg ~ hp + factor(am) + wt, mtcars)
+nd <- data.frame(hp = 120, am = 1)
+expect_warning(comparisons(mod, variables = "wt", newdata = nd), pattern = "explicitly")
+expect_error(suppressWarnings(comparisons(mod, variables = "wt", newdata = nd)))
+nd <- data.frame(hp = 120, wt = 2.5)
+cmp <- comparisons(mod, variables = "am", newdata = nd)
+expect_inherits(cmp, "comparisons")
+expect_warning(comparisons(mod, newdata = nd), pattern = "is included")
+expect_error(suppressWarnings(comparisons(mod, newdata = nd), pattern = "is included"))
+
+
+
+# comparisons() variables = data.frame()
+mod <- lm(mpg ~ hp, mtcars)
+comparisons(mod, variables = list(hp = data.frame(mtcars$hp, mtcars$hp + 1:32)))
+
+
+
+rm(list = ls())
\ No newline at end of file
